@@ -1,4 +1,4 @@
-from os import path
+from os import path, remove
 from shutil import move
 from pmanager.res import *
 
@@ -29,6 +29,13 @@ def initialize(namespace):
             archive_dirpath = f.read()+"/"+ project_name +"/"
 
 
+
+    #remove the custom startup command if there is one
+
+    if path.exists("config/{project_name}.xml"):
+        remove(f"config/{project_name}.xml")
+
+
     pinfo(f"opening project folder : \n {dirpath}")
 
     pinfo(f"moving it to : \n {archive_dirpath}")
